# graphflow : Algorithms for Graph Flow Analysis

[![Build Status](https://travis-ci.org/stephenhky/GraphFlow.svg?branch=master)](https://travis-ci.org/stephenhky/GraphFlow)
[![GitHub release](https://img.shields.io/github/release/stephenhky/GraphFlow.svg?maxAge=3600)](https://github.com/stephenhky/GraphFlow/releases)
[![Documentation Status](https://readthedocs.org/projects/graphflow/badge/?version=latest)](https://graphflow.readthedocs.io/en/latest/?badge=latest)

This Python package provides numerical routines for graph flow analysis, particularly:

* PageRank
* Linear System of Resistance
* Non-linear System of Resistance
* HITS (Hyperlink-Induced Topic Search)

# Installation

You must have `numpy` pre-installed. GCC and GFORTRAN compilers have to be available in the machine.
After ensuring they have been installed, type the following to install `graphflow`:

```
>>> pip install -U graphflow
```

# News

* 04/07/2020: `graphflow` 0.2.1 released.
* 09/12/2018: `graphflow` 0.2.0 released.
* 09/03/2018: `graphflow` 0.1.6 released.
* 07/19/2018: `graphflow` 0.1.5 released.
* 06/27/2018: `graphflow` 0.1.4 released.
* 06/14/2018: `graphflow` 0.1.3 released.
* 06/06/2018: `graphflow` 0.1.2 released.
* 04/12/2018: `graphflow` 0.1.1 released.
